Crate scythe_codegen

Crate scythe_codegen 

Re-exports

pub use backend_trait::CodegenBackend;
pub use backend_trait::ResolvedColumn;
pub use backend_trait::ResolvedParam;
pub use backends::get_backend;

Modules

backend_trait
backends
resolve
validation

Structs

GeneratedCode

Functions

generate
Backward-compatible: generate code using the default sqlx backend.
generate_from_catalog
Stub for catalog-level codegen. Returns default for now.
generate_single_enum_def
Backward-compatible: generate a single enum definition (sqlx backend). Uses the manifest directly for backward compatibility with existing callers.
generate_single_enum_def_with_backend
Generate a single enum definition using a specific backend.
generate_with_backend
Generate code using a specific backend.
get_manifest_for_backend
Get the manifest for a backend. Defaults to PostgreSQL engine.
load_or_default_manifest
Backward-compatible: load the default sqlx manifest.