Module backend_trait

Module backend_trait 

Structs

RbsEnumInfo
Per-enum info for RBS generation.
RbsGenerationContext
Information needed to generate an RBS type signature file.
RbsQueryInfo
Per-query info for RBS generation.
ResolvedColumn
A column with its type resolved to the target language.
ResolvedParam
A parameter with its type resolved to the target language.

Traits

CodegenBackend
Trait that all codegen backends must implement.