Module overrides

Module overrides 

Structs

TypeOverride
A type override that replaces the inferred neutral type for a column or SQL type.

Functions

find_override
Find the first override that matches a column and return its neutral type.