Module backend_trait
scythe_
codegen
0.4.0
Module backend_
trait
Module Items
Structs
Traits
In crate scythe_
codegen
scythe_codegen
Module
backend_
trait
Structs

Resolved
Column
A column with its type resolved to the target language.
Resolved
Param
A parameter with its type resolved to the target language.
Traits

Codegen
Backend
Trait that all codegen backends must implement.