Module backend_trait

Module backend_trait 

Structs

ResolvedColumn
A column with its type resolved to the target language.
ResolvedParam
A parameter with its type resolved to the target language.

Traits

CodegenBackend
Trait that all codegen backends must implement.