Module overrides
scythe_
codegen
0.6.9
Module overrides
Module Items
Structs
Functions
In crate scythe_
codegen
scythe_codegen
Module
overrides
Structs

Type
Override
A type override that replaces the inferred neutral type for a column or SQL type.
Functions

find_
override
Find the first override that matches a column and return its neutral type.